<?xml version="1.0" encoding="UTF-8"?>
<!-- 
  ======================================================================
  このスタイルシートは、「気象庁防災情報XMLフォーマット」に対して活用事例を示すサンプルであり、資料として参照することを目的とする。
  よって、本スタイルシートを直接利用した場合に発生する問題に対して、気象庁は責任を負わない。
  Copyright (c) 気象庁 2010 All rights reserved.

  【本スタイルシートの説明】
　火山現象に関する海上警報のXML電文を現行テキスト電文に近い形で表示させる例

  【更新履歴】
  2010年04月30日　Ver.1.0 　地震火山部火山課
  ======================================================================
  --> 
<xsl:stylesheet xmlns:jmx="http://xml.kishou.go.jp/jmaxml1/"
 xmlns:jmx_ib="http://xml.kishou.go.jp/jmaxml1/informationBasis1/"
 xmlns:jmx_volc="http://xml.kishou.go.jp/jmaxml1/body/volcanology1/"
 xmlns:jmx_eb="http://xml.kishou.go.jp/jmaxml1/elementBasis1/"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
 <xsl:output method="html" encoding="UTF-8" />

<!-- 文書 -->
<xsl:template match="/">
  <html>
    <xsl:apply-templates select="/jmx:Report"/>
  </html>
</xsl:template>

<!-- 電文 -->
<xsl:template match="/jmx:Report">
  <head>
    <xsl:apply-templates select="jmx:Control"/>
  </head>
  <body>
    <xsl:apply-templates select="jmx_ib:Head"/>
    <xsl:apply-templates select="jmx_volc:Body"/>
  </body>
</xsl:template>

<!-- コントロール部 -->
<xsl:template match="jmx:Control">
  <xsl:copy-of select="jmx:Title"/>
</xsl:template>

<!-- ヘッド部 -->
<xsl:template match="jmx_ib:Head">
  <div align="left">
    <h1><xsl:value-of select="jmx_ib:Title"/></h1>
    <p>
      <xsl:value-of select="substring-before(jmx_ib:TargetDateTime,'-')"/>  <xsl:text>年</xsl:text>
      <xsl:value-of select="substring(jmx_ib:TargetDateTime,6,2)"/>         <xsl:text>月</xsl:text>
      <xsl:value-of select="substring(jmx_ib:TargetDateTime,9,2)"/>         <xsl:text>日</xsl:text>
      <xsl:value-of select="substring(jmx_ib:TargetDateTime,12,2)"/>        <xsl:text>時</xsl:text>
      <xsl:value-of select="substring(jmx_ib:TargetDateTime,15,2)"/>        <xsl:text>分　</xsl:text>
      <xsl:text>観測</xsl:text>
      <br/>
      <xsl:value-of select="substring-before(jmx_ib:ReportDateTime,'-')"/>  <xsl:text>年</xsl:text>
      <xsl:value-of select="substring(jmx_ib:ReportDateTime,6,2)"/>         <xsl:text>月</xsl:text>
      <xsl:value-of select="substring(jmx_ib:ReportDateTime,9,2)"/>         <xsl:text>日</xsl:text>
      <xsl:value-of select="substring(jmx_ib:ReportDateTime,12,2)"/>        <xsl:text>時</xsl:text>
      <xsl:value-of select="substring(jmx_ib:ReportDateTime,15,2)"/>        <xsl:text>分　</xsl:text>
      <xsl:value-of select="jmx_ib:InfoStatus"/>                            <xsl:text>　　</xsl:text>
      <xsl:value-of select="/jmx:Report/jmx:Control/jmx:PublishingOffice"/>
    </p>
  </div>
</xsl:template>

<!-- ボディ部 -->
<xsl:template match="jmx_volc:Body">
  <div><xsl:apply-templates select="jmx_volc:VolcanoInfo[@type='噴火警報・予報（対象火山）']"/></div>
  <div><xsl:apply-templates select="jmx_volc:VolcanoInfo[@type='火山現象に関する海上警報・海上予報（対象海上予報区）']"/></div>
  <div><xsl:apply-templates select="jmx_volc:VolcanoInfoContent"/></div>
</xsl:template>

<!-- ボディ部＞噴火警報・予報（対象火山） -->
<xsl:template match="jmx_volc:VolcanoInfo[@type='噴火警報・予報（対象火山）']">
  <h3><xsl:text>火山名</xsl:text></h3>
  <p><xsl:value-of select="jmx_volc:Item/jmx_volc:Areas[@codeType='火山名']/jmx_volc:Area/jmx_volc:Name"/></p>
  <h3><xsl:text>位置</xsl:text></h3>
  <p><xsl:value-of select="jmx_volc:Item/jmx_volc:Areas[@codeType='火山名']/jmx_volc:Area/jmx_volc:Coordinate/@description"/><br/>
     <xsl:value-of select="jmx_volc:Item/jmx_volc:Areas[@codeType='火山名']/jmx_volc:Area/jmx_volc:AreaFromMark"/></p>
  <h3><xsl:text>警戒事項等（キーワード）</xsl:text></h3>
  <p><xsl:value-of select="jmx_volc:Item/jmx_volc:Kind/jmx_volc:Name"/></p>
</xsl:template>

<!-- ボディ部＞火山現象に関する海上警報・海上予報（対象海上予報区） -->
<xsl:template match="jmx_volc:VolcanoInfo[@type='火山現象に関する海上警報・海上予報（対象海上予報区）']">
  <h3><xsl:text>対象海上予報区</xsl:text></h3>
  <p><xsl:value-of select="jmx_volc:Item/jmx_volc:Areas[@codeType='地方海上予報区']/jmx_volc:Area/jmx_volc:Name"/></p>
</xsl:template>

<!-- ボディ部＞防災事項 -->
<xsl:template match="jmx_volc:VolcanoInfoContent">
  <h3><xsl:text>防災事項</xsl:text></h3>
  <p><xsl:value-of select="jmx_volc:VolcanoPrevention"/></p>
</xsl:template>

</xsl:stylesheet>
